==> haskell-cmark-0.5.6-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cmark.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cmark
version: 0.5.6
id: cmark-0.5.6-EsjzmWfoyko59GqsfxKW0P
key: cmark-0.5.6-EsjzmWfoyko59GqsfxKW0P
license: BSD3
copyright: (C) 2015--17 John MacFarlane
maintainer: jgm@berkeley.edu
homepage: https://github.com/jgm/cmark-hs
synopsis: Fast, accurate CommonMark (Markdown) parser and renderer
description:
    This package provides Haskell bindings for
    <https://github.com/jgm/cmark libcmark>, the reference
    parser for <http://commonmark.org CommonMark>, a fully
    specified variant of Markdown. It includes sources for
    libcmark (0.28.0) and does not require prior installation of the
    C library.
category: Text
author: John MacFarlane
exposed: True
indefinite: False
exposed-modules:
    CMark
abi: 0b1bf0d7be5403ab215e6ae97dec5db7
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/cmark-0.5.6
library-dirs: /usr/lib/ghc-8.2.2/site-local/cmark-0.5.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/cmark-0.5.6
hs-libraries: HScmark-0.5.6-EsjzmWfoyko59GqsfxKW0P
extra-libraries:
    cmark
depends:
    base-4.10.1.0 text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj
    bytestring-0.10.8.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj=19cd54ed0f93cc2e72d3ff0c754f5306
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
haddock-interfaces: /usr/share/doc/haskell-cmark/html/cmark.haddock
haddock-html: /usr/share/doc/haskell-cmark/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cmark-0.5.6-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cmark.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cmark
version: 0.5.6
id: cmark-0.5.6-GOxMLW6CNvDGdoQGpA4CIP
key: cmark-0.5.6-GOxMLW6CNvDGdoQGpA4CIP
license: BSD3
copyright: (C) 2015--17 John MacFarlane
maintainer: jgm@berkeley.edu
homepage: https://github.com/jgm/cmark-hs
synopsis: Fast, accurate CommonMark (Markdown) parser and renderer
description:
    This package provides Haskell bindings for
    <https://github.com/jgm/cmark libcmark>, the reference
    parser for <http://commonmark.org CommonMark>, a fully
    specified variant of Markdown. It includes sources for
    libcmark (0.28.0) and does not require prior installation of the
    C library.
category: Text
author: John MacFarlane
exposed: True
indefinite: False
exposed-modules:
    CMark
abi: 725b9412cc8638c8eba2a9fdd72c46aa
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/cmark-0.5.6
library-dirs: /usr/lib/ghc-8.2.2/site-local/cmark-0.5.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/cmark-0.5.6
hs-libraries: HScmark-0.5.6-GOxMLW6CNvDGdoQGpA4CIP
extra-libraries:
    cmark
depends:
    base-4.10.1.0 text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
    bytestring-0.10.8.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
haddock-interfaces: /usr/share/doc/haskell-cmark/html/cmark.haddock
haddock-html: /usr/share/doc/haskell-cmark/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
